@@ -20,7 +20,7 @@ patchsysdict = {0: 'stdin', 1: 'stdout', 2: 'stderr'}
 def pytest_addoption(parser):
     group = parser.getgroup("general")
     group._addoption(
-        '--capture', action="store", 
+        '--capture', action="store",
         default="fd" if hasattr(os, "dup") else "sys",
         metavar="method", choices=['fd', 'sys', 'no'],
         help="per-test capturing method: one of fd|sys|no.")
@@ -33,8 +33,6 @@ def pytest_addoption(parser):
 def pytest_load_initial_conftests(early_config, parser, args, __multicall__):
     ns = early_config.known_args_namespace
     pluginmanager = early_config.pluginmanager
-    if ns.capture == "no":
-        return
     capman = CaptureManager(ns.capture)
     pluginmanager.register(capman, "capturemanager")
 
@@ -225,6 +223,7 @@ def safe_text_dupfile(f, mode, default_encoding="UTF8"):
 
 
 class EncodedFile(object):
+    errors = "strict"  # possibly needed by py3 code (issue555)
     def __init__(self, buffer, encoding):
         self.buffer = buffer
         self.encoding = encoding
@@ -239,7 +238,7 @@ class EncodedFile(object):
         self.write(data)
 
     def __getattr__(self, name):
-        return getattr(self.buffer, name)
+        return getattr(object.__getattribute__(self, "buffer"), name)
 
 
 class MultiCapture(object):
@@ -429,6 +428,9 @@ class DontReadFromInput:
     because in automated test runs it is better to crash than
     hang indefinitely.
     """
+
+    encoding = None
+
     def read(self, *args):
         raise IOError("reading from stdin while output is captured")
     readline = read
