@@ -1,6 +1,7 @@
 # note: py.io capture tests where copied from
 # pylib 1.4.20.dev2 (rev 13d9af95547e)
 from __future__ import with_statement
+import pickle
 import os
 import sys
 import py
@@ -743,6 +744,7 @@ class TestFDCapture:
             cap.done()
             pytest.raises(AttributeError, cap.suspend)
 
+
 @contextlib.contextmanager
 def saved_fd(fd):
     new_fd = os.dup(fd)
@@ -750,6 +752,7 @@ def saved_fd(fd):
         yield
     finally:
         os.dup2(new_fd, fd)
+        os.close(new_fd)
 
 
 class TestStdCapture:
@@ -1022,3 +1025,24 @@ def test_error_attribute_issue555(testdir):
     """)
     reprec = testdir.inline_run()
     reprec.assertoutcome(passed=1)
+
+
+def test_dontreadfrominput_has_encoding(testdir):
+    testdir.makepyfile("""
+        import sys
+        def test_capattr():
+            # should not raise AttributeError
+            assert sys.stdout.encoding
+            assert sys.stderr.encoding
+    """)
+    reprec = testdir.inline_run()
+    reprec.assertoutcome(passed=1)
+
+
+def test_pickling_and_unpickling_enocded_file():
+    # See https://bitbucket.org/hpk42/pytest/pull-request/194
+    # pickle.loads() raises infinite recursion if
+    # EncodedFile.__getattr__ is not implemented properly
+    ef = capture.EncodedFile(None, None)
+    ef_as_str = pickle.dumps(ef)
+    pickle.loads(ef_as_str)
