@@ -79,6 +79,21 @@ class TestConfigCmdlineParsing:
         config = testdir.parseconfig()
         pytest.raises(AssertionError, lambda: config.parse([]))
 
+    def test_explicitly_specified_config_file_is_loaded(self, testdir):
+        testdir.makeconftest("""
+            def pytest_addoption(parser):
+                parser.addini("custom", "")
+        """)
+        testdir.makeini("""
+            [pytest]
+            custom = 0
+        """)
+        testdir.makefile(".cfg", custom = """
+            [pytest]
+            custom = 1
+        """)
+        config = testdir.parseconfig("-c", "custom.cfg")
+        assert config.getini("custom") == "1"
 
 class TestConfigAPI:
     def test_config_trace(self, testdir):
@@ -89,20 +104,6 @@ class TestConfigAPI:
         assert len(l) == 1
         assert l[0] == "hello [config]\n"
 
-    def test_config_getvalue_honours_conftest(self, testdir):
-        testdir.makepyfile(conftest="x=1")
-        testdir.mkdir("sub").join("conftest.py").write("x=2 ; y = 3")
-        config = testdir.parseconfig()
-        o = testdir.tmpdir
-        assert config.getvalue("x") == 1
-        assert config.getvalue("x", o.join('sub')) == 2
-        pytest.raises(KeyError, "config.getvalue('y')")
-        config = testdir.parseconfigure(str(o.join('sub')))
-        assert config.getvalue("x") == 2
-        assert config.getvalue("y") == 3
-        assert config.getvalue("x", o) == 1
-        pytest.raises(KeyError, 'config.getvalue("y", o)')
-
     def test_config_getoption(self, testdir):
         testdir.makeconftest("""
             def pytest_addoption(parser):
@@ -130,34 +131,29 @@ class TestConfigAPI:
             "config.getvalueorskip('hello')")
         verbose = config.getvalueorskip("verbose")
         assert verbose == config.option.verbose
-        config.option.hello = None
-        try:
-            config.getvalueorskip('hello')
-        except KeyboardInterrupt:
-            raise
-        except:
-            excinfo = py.code.ExceptionInfo()
-        frame = excinfo.traceback[-2].frame
-        assert frame.code.name == "getvalueorskip"
-        assert frame.eval("__tracebackhide__")
 
-    def test_config_overwrite(self, testdir):
-        o = testdir.tmpdir
-        o.ensure("conftest.py").write("x=1")
-        config = testdir.parseconfig(str(o))
-        assert config.getvalue('x') == 1
-        config.option.x = 2
-        assert config.getvalue('x') == 2
-        config = testdir.parseconfig([str(o)])
-        assert config.getvalue('x') == 1
+    def test_config_getvalueorskip_None(self, testdir):
+        testdir.makeconftest("""
+            def pytest_addoption(parser):
+                parser.addoption("--hello")
+        """)
+        config = testdir.parseconfig()
+        with pytest.raises(pytest.skip.Exception):
+            config.getvalueorskip('hello')
+
+    def test_getoption(self, testdir):
+        config = testdir.parseconfig()
+        with pytest.raises(ValueError):
+            config.getvalue('x')
+        assert config.getoption("x", 1) == 1
 
     def test_getconftest_pathlist(self, testdir, tmpdir):
         somepath = tmpdir.join("x", "y", "z")
         p = tmpdir.join("conftest.py")
         p.write("pathlist = ['.', %r]" % str(somepath))
         config = testdir.parseconfigure(p)
-        assert config._getconftest_pathlist('notexist') is None
-        pl = config._getconftest_pathlist('pathlist')
+        assert config._getconftest_pathlist('notexist', path=tmpdir) is None
+        pl = config._getconftest_pathlist('pathlist', path=tmpdir)
         print(pl)
         assert len(pl) == 2
         assert pl[0] == tmpdir
@@ -360,4 +356,43 @@ def test_load_initial_conftest_last_ordering(testdir):
     assert l[-2] == m.pytest_load_initial_conftests
     assert l[-3].__module__ == "_pytest.config"
 
+class TestWarning:
+    def test_warn_config(self, testdir):
+        testdir.makeconftest("""
+            l = []
+            def pytest_configure(config):
+                config.warn("C1", "hello")
+            def pytest_logwarning(code, message):
+                assert code == "C1"
+                assert message == "hello"
+                l.append(1)
+        """)
+        testdir.makepyfile("""
+            def test_proper(pytestconfig):
+                import conftest
+                assert conftest.l == [1]
+        """)
+        reprec = testdir.inline_run()
+        reprec.assertoutcome(passed=1)
 
+    def test_warn_on_test_item_from_request(self, testdir):
+        testdir.makepyfile("""
+            import pytest
+
+            @pytest.fixture
+            def fix(request):
+                request.node.warn("T1", "hello")
+            def test_hello(fix):
+                pass
+        """)
+        result = testdir.runpytest()
+        result.stdout.fnmatch_lines("""
+            *1 warning*
+        """)
+        assert "hello" not in result.stdout.str()
+        result = testdir.runpytest("-rw")
+        result.stdout.fnmatch_lines("""
+            ===*warning summary*===
+            *WT1*test_warn_on_test_item*:5*hello*
+            *1 warning*
+        """)
