@@ -15,6 +15,10 @@ class TestMark:
         mark = Mark()
         pytest.raises((AttributeError, TypeError), mark)
 
+    def test_pytest_mark_name_starts_with_underscore(self):
+        mark = Mark()
+        pytest.raises(AttributeError, getattr, mark, '_some_name')
+
     def test_pytest_mark_bare(self):
         mark = Mark()
         def f():
@@ -53,6 +57,17 @@ class TestMark:
         assert f.world.args[0] == "hello"
         mark.world("world")(f)
 
+    def test_pytest_mark_positional_func_and_keyword(self):
+        mark = Mark()
+        def f():
+            raise Exception
+        m = mark.world(f, omega="hello")
+        def g():
+            pass
+        assert m(g) == g
+        assert g.world.args[0] is f
+        assert g.world.kwargs["omega"] == "hello"
+
     def test_pytest_mark_reuse(self):
         mark = Mark()
         def f():
@@ -100,6 +115,28 @@ def test_markers_option(testdir):
         "*a1some*another marker",
     ])
 
+def test_markers_option_with_plugin_in_current_dir(testdir):
+    testdir.makeconftest('pytest_plugins = "flip_flop"')
+    testdir.makepyfile(flip_flop="""\
+        def pytest_configure(config):
+            config.addinivalue_line("markers", "flip:flop")
+
+        def pytest_generate_tests(metafunc):
+            try:
+                mark = metafunc.function.flipper
+            except AttributeError:
+                return
+            metafunc.parametrize("x", (10, 20))""")
+    testdir.makepyfile("""\
+        import pytest
+        @pytest.mark.flipper
+        def test_example(x):
+            assert x""")
+
+    result = testdir.runpytest("--markers")
+    result.stdout.fnmatch_lines(["*flip*flop*"])
+
+
 def test_mark_on_pseudo_function(testdir):
     testdir.makepyfile("""
         import pytest
