@@ -45,6 +45,12 @@ class TestSetattrWithImportPath:
         import _pytest
         assert _pytest.config.Config == 42
 
+    def test_unicode_string(self, monkeypatch):
+        monkeypatch.setattr("_pytest.config.Config", 42)
+        import _pytest
+        assert _pytest.config.Config == 42
+        monkeypatch.delattr("_pytest.config.Config")
+
     def test_wrong_target(self, monkeypatch):
         pytest.raises(TypeError, lambda: monkeypatch.setattr(None, None))
 
